/* 
 *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
 *    Copyright 2018, 2024 (c)
 * 
 *    file: modules.h
 *    This file is part of mino.
 *
 *    mino is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    mino is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
 */    
#ifndef __MODULES_H
#define __MODULES_H

// include the highlight modes enum
#include "../options.h"

struct modulestruct
{
    int extsCount;
    char **exts;
    int keywordCount;
    wchar_t **keywords;
    // for multi-line comments
    wchar_t *mlCommentStart;
    wchar_t *mlCommentEnd;
    // for single-line comments
    wchar_t *slCommentStart;
    // treat keywords as case-sensitive
    char caseSensitive;
};

#define NUM_MODULES     12

extern struct modulestruct *module[];
extern struct modulestruct *curmodule;
extern struct modulestruct dummyModule;

#endif
